# Magic-XXL

Personal tool box compatible with flask-magic

---

## Taskman

A queue system using Amazon SQS

---

## Redis Collection

Redis extension that uses native List, Dict, Set


---

## Elasticsearch Index

Elasticsearch wrapper's wrapper for search 

--- 

## Flask Rollbar Logger

To log events on roll bar

---

## Flask New Relic APM

Monitor App on New Relic 

